**Example 1: Sample request**



Input: 

```
tccli mdl ModifyMediaLiveInputSecurityGroup --cli-unfold-argument  \
    --Id ' 1111' \
    --Name xxxx
```

Output: 
```
{
    "Response": {
        "RequestId": "3c140219-cfe9-470e-b241-907877d6fb03"
    }
}
```

